---
url: https://www.normattiva.it/uri-res/N2Ls?urn:nir:stato:decreto.legislativo:2009-12-01;177
url_xml: https://www.normattiva.it/do/atto/caricaAKN?dataGU=20091214&codiceRedaz=009G0189&dataVigenza=20251104
dataGU: 20091214
codiceRedaz: 009G0189
dataVigenza: 20251104
---

# Riorganizzazione del Centro nazionale per l'informatica nella pubblica amministrazione, a norma dell'articolo 24 della legge 18 giugno 2009, n. 69. (09G0189)

IL PRESIDENTE DELLA REPUBBLICA

Visti gli articoli 76, 87, 92, 95 e 117 della Costituzione;

Vista la legge 18 giugno 2009, n. 69, recante disposizioni per lo sviluppo economico, la semplificazione, la competitivita' nonche' in materia di processo civile, ed in particolare, l'articolo 24 che delega il Governo ad adottare uno o piu' decreti legislativi per il riordino, tra l'altro, del Centro nazionale per l'informatica nella pubblica amministrazione (CNIPA);

Vista la legge 23 agosto 1988, n. 400, recante disciplina dell'attivita' di Governo e ordinamento della Presidenza del Consiglio dei Ministri, e successive modificazioni;

Visto l'articolo 2, comma 1, lettera mm), della legge 23 ottobre 1992, n. 421, recante delega al Governo per la razionalizzazione e la revisione delle discipline in materia di sanita', di pubblico impiego, di previdenza e di finanza territoriale, e successive modificazioni;

Visto il decreto legislativo 12 febbraio 1993, n. 39, recante norme in materia di sistemi informativi automatizzati delle amministrazioni pubbliche, a norma dell'articolo 2, comma 1, lettera mm), della legge 23 ottobre 1992, n. 421, e successive modificazioni;

Visto il decreto del Presidente del Consiglio dei Ministri 14 aprile 1994, n. 609, recante regolamento recante norme per l'organizzazione ed il funzionamento dell'Autorita' per l'informatica nella pubblica amministrazione;

Visto il decreto legislativo 30 luglio 1999, n. 286, recante riordino e potenziamento dei meccanismi e strumenti di monitoraggio e valutazione dei costi, dei rendimenti e dei risultati dell'attivita' svolta dalle amministrazioni pubbliche, a norma dell'articolo 11 della legge 15 marzo 1997, n. 59, e successive modificazioni;

Visto il decreto legislativo 30 luglio 1999, n. 303, recante ordinamento della Presidenza del Consiglio dei Ministri, a norma dell'articolo 11 della legge 15 marzo 1997, n. 59, e successive modificazioni;

Visto il decreto legislativo 30 marzo 2001, n. 165, recante norme generali sull'ordinamento del lavoro alle dipendenze delle amministrazioni pubbliche, e successive modificazioni;

Visto il decreto legislativo 30 giugno 2003, n. 196, recante codice in materia di protezione dei dati personali ed, in particolare, l'articolo 176;

Visto il decreto-legge 31 gennaio 2005, n. 7, recante disposizioni urgenti per l'universita' e la ricerca, per i beni e le attivita' culturali, per il completamento di grandi opere strategiche, per la mobilita' dei pubblici dipendenti, e per semplificare gli adempimenti relativi a imposte di bollo e tasse di concessione, nonche' altre misure urgenti, convertito, con modificazioni, dalla legge 31 marzo 2005, n. 43, che ha inserito il Centro nazionale per l'informatica nella pubblica amministrazione tra gli enti di cui all'articolo 70, comma 4, del decreto legislativo 30 marzo 2001, n. 165;

Visto il Codice dell'amministrazione digitale di cui al decreto legislativo 7 marzo 2005, n. 82, e successive modificazioni;

Visto l'articolo 1, comma 188, della legge 23 dicembre 2005, n. 266, recante disposizioni per la formazione del bilancio annuale e pluriennale dello Stato (legge finanziaria 2006);

Visto l'articolo 2, commi 634 e 635, della legge 24 dicembre 2007, n. 244, recante disposizioni per la formazione del bilancio annuale e pluriennale dello Stato (legge finanziaria 2008), e successive modificazioni;

Visto l'articolo 17, commi da 20 a 22, del decreto-legge 1° luglio 2009, n. 78, convertito, con modificazioni, dalla legge 3 agosto 2009, n. 102, recante provvedimenti anticrisi, nonche' proroga di termini e della partecipazione italiana a missioni internazionali;

Visto il decreto legislativo 27 ottobre 2009, n. 150, recante attuazione della legge 4 marzo 2009, n. 15, in materia di ottimizzazione della produttivita' del lavoro pubblico e di efficienza e trasparenza delle pubbliche amministrazioni;

Visto il decreto del Presidente del Consiglio dei Ministri 1° giugno 2007, n. 110, recante il nuovo regolamento per la gestione delle spese del Centro nazionale per l'informatica nella pubblica amministrazione;

Vista la preliminare deliberazione del Consiglio dei Ministri, adottata nella riunione del 24 luglio 2009;

Acquisito il parere della Commissione parlamentare di cui all'articolo 14, comma 19, della legge 28 novembre 2005, n. 246;

Vista la deliberazione del Consiglio dei Ministri, adottata nella riunione del 6 novembre 2009;

Sulla proposta del Ministro per la pubblica amministrazione e l'innovazione, di concerto con il Ministro dell'economia e delle finanze, del Ministro per i rapporti con le Regioni e del Ministro per l'attuazione del programma di Governo;

Emana il seguente decreto legislativo:

## Disposizioni generali

### Art. 1. - Oggetto

1. Il presente decreto provvede al riordino della disciplina del Centro nazionale per l'informatica nella pubblica amministrazione (CNIPA), ai sensi dell'articolo 24, della legge 18 giugno 2009 n. 69.

### Art. 2. - Natura e finalita' dell'Ente

1. Ai sensi dell'articolo 1, il Centro nazionale per l'informatica nella pubblica amministrazione, di seguito denominato: «CNIPA» assume la denominazione: «DigitPA».

2. DigitPA e' un ente pubblico non economico, con sede in Roma e competenza nel settore delle tecnologie dell'informazione e della comunicazione nell'ambito della pubblica amministrazione; esso opera secondo le direttive, per l'attuazione delle politiche e sotto la vigilanza del Presidente del Consiglio dei Ministri o del Ministro delegato, con autonomia tecnica e funzionale, amministrativa, contabile, finanziaria e patrimoniale.

3. DigitPA svolge funzioni di natura progettuale, tecnica e operativa, con la missione di contribuire alla creazione di valore per cittadini e imprese da parte della pubblica amministrazione, attraverso la realizzazione dell'amministrazione digitale.

### Art. 3. - Funzioni

1. Al fine di conseguire le finalita' di cui all'articolo 2, DigitPA opera, nell'ambito delle direttive del Presidente del Consiglio dei Ministri o del Ministro delegato, ed in coerenza con il Piano ICT nella pubblica amministrazione centrale, di cui all'articolo 22, comma 1, sulla base di un Piano triennale per la programmazione di propri obiettivi ed attivita', aggiornato annualmente, nel quale sono determinate le metodologie per il raggiungimento dei risultati attesi, le risorse umane e finanziarie necessarie al fine. Il Piano triennale e' approvato con decreto del Presidente del Consiglio dei Ministri o del Ministro delegato, di concerto con il Ministro dell'economia e delle finanze.

2. A DigitPA, in particolare, sono affidate le seguenti funzioni:

- a) funzioni di consulenza e proposta. L'Ente fornisce assistenza tecnica, anche nella elaborazione di studi e schemi di atti normativi, al Presidente del Consiglio dei Ministri o al Ministro da lui delegato in materia di amministrazione digitale; in coerenza con le indicazioni della Conferenza unificata, fornisce collaborazioni tecniche e consulenza tecnica alle regioni e agli enti locali in materia di innovazione tecnologica e di informatizzazione, anche per l'utilizzo delle relative risorse finanziarie pubbliche; propone, ai fini della pianificazione triennale dell'ICT, iniziative finalizzate alla realizzazione di sistemi innovativi in materia di ICT; svolge, anche sulla base di apposite convenzioni, attivita' di supporto, consulenza e assistenza per amministrazioni pubbliche ed organismi di diritto pubblico, anche prevedendo il ristoro dei costi sostenuti;
- b) funzioni di emanazione di regole, standard e guide tecniche, nonche' di vigilanza e controllo sul rispetto di norme. L'Ente fissa regole tecniche, standard e guide tecniche, anche attraverso atti amministrativi generali; rende pareri su atti normativi nei casi previsti dall'ordinamento; opera come autorita' di certificazione della firma digitale ed e' preposto alla tenuta di elenchi e registri nei casi previsti dall'ordinamento; contribuisce all'attuazione di iniziative volte all'attivita' di informatizzazione della normativa statale vigente;
- c) funzioni di valutazione, di monitoraggio e di coordinamento. L'Ente formula pareri alle amministrazioni sulla coerenza strategica e sulla congruita' economica e tecnica degli interventi e dei contratti relativi all'acquisizione di beni e servizi informatici e telematici, anche ai sensi del comma 3, e monitora l'esecuzione degli interventi e dei contratti suddetti; svolge attivita' di monitoraggio dell'attuazione dei piani di ICT delle pubbliche amministrazioni; coordina, ove richiesto, le attivita' delle singole amministrazioni e ne verifica i risultati sotto il profilo dell'efficienza, efficacia e qualita' dei sistemi informativi; effettua valutazioni, preventive e successive, sull'impatto di iniziative innovative nel settore dell'ICT;
- d) funzioni di predisposizione, realizzazione e gestione di interventi e progetti di innovazione. DigitPA propone progetti in tema di amministrazione digitale; realizza e gestisce, direttamente o avvalendosi di soggetti terzi, specifici progetti in tema di amministrazione digitale ad esso assegnati; effettua, anche in partenariato, attivita' di studio, ricerca, sviluppo e sperimentazione in materia di ICT, relazionando al Presidente del Consiglio dei Ministri o al Ministro delegato; svolge i compiti ad esso attribuiti dall'ordinamento in materia di reti telematiche delle pubbliche amministrazioni, di Sistema Pubblico di Connettivita' (SPC) e di Rete Internazionale della Pubblica Amministrazione (RIPA); svolge, secondo le modalita' previste dall'ordinamento, compiti tecnico-operativi in materia di formazione informatica del personale delle pubbliche amministrazioni.

3. DigitPA esprime pareri tecnici, obbligatori e non vincolanti, sugli schemi di contratti stipulati dalle pubbliche amministrazioni centrali concernenti l'acquisizione di beni e servizi relativi ai sistemi informativi automatizzati per quanto concerne la congruita' tecnico-economica, qualora il valore lordo di detti contratti sia superiore a euro 1.000.000,00 nel caso di procedura negoziata e a euro 2.000.000,00 nel caso di procedura ristretta o di procedura aperta. ((Tali pareri sono facoltativi per le centrali di committenza e per le amministrazioni che ad esse ricorrono per le acquisizioni di beni e servizi)). Il parere dell'Ente e' reso entro il termine di quarantacinque giorni dal ricevimento della relativa richiesta. Si applicano le disposizioni dell'articolo 16 della legge 7 agosto 1990, n. 241 e successive modificazioni. Copia dei pareri tecnici attinenti a questioni di competenza dell'Autorita' per la vigilanza sui contratti pubblici di lavori, servizi e forniture e' trasmessa da DigitPA a detta Autorita'.

4. Fermo restando quanto disposto all'articolo 22, l'Ente svolge ogni altra funzione prevista da leggi e regolamenti gia' attribuita al CNIPA, nell'ambito delle direttive del Presidente del Consiglio dei Ministri o del Ministro delegato.

## Organi e Direttore Generale

### Art. 4. - Organi

1. Sono organi di DigitPA:

- a) il Presidente;
- b) il Comitato direttivo;
- c) il Collegio dei revisori.

### Art. 5. - Il Presidente

1. Il Presidente e' scelto fra persone di alta qualificazione tecnica e manageriale con profonda conoscenza in materia di innovazione tecnologica comprovata da competenze in ambito scientifico e da esperienza di gestione di enti o strutture complesse, pubbliche o private. E' nominato con decreto del Presidente della Repubblica, su proposta del Presidente del Consiglio dei Ministri o del Ministro delegato, previa deliberazione del Consiglio dei Ministri. Dura in carica quattro anni e puo' essere confermato una sola volta. Se dipendente statale o docente universitario, per l'intera durata dell'incarico, e' collocato, rispettivamente, nella posizione di fuori ruolo o di aspettativa.

2. Il Presidente ha la rappresentanza legale di DigitPA e cura i rapporti esterni con le istituzioni e le amministrazioni pubbliche nazionali, comunitarie ed internazionali.

3. Il Presidente, che e' responsabile dell'attivita' dell'Ente sotto il profilo tecnico e scientifico, predispone il Piano triennale di cui all'articolo 3, comma 1, che sottopone alla deliberazione del Comitato direttivo e ne garantisce l'attuazione.

4. Il Presidente, sentito il Comitato direttivo valuta il raggiungimento degli obiettivi strategici di cui al Piano triennale previsto dall'articolo 3, comma 1.

5. Il Presidente convoca, presiede e stabilisce l'ordine del giorno del Comitato direttivo. In caso di urgenza, provvede alle deliberazioni di competenza del Comitato direttivo, da sottoporre a ratifica nella prima seduta successiva. In caso di assenza o impedimento il Presidente e' sostituito da un vice Presidente, nominato dal Comitato direttivo fra i suoi componenti, cui il Presidente puo' conferire specifiche deleghe, senza maggiori oneri.

6. Il Presidente puo' delegare proprie funzioni ai componenti del Comitato direttivo di cui all'articolo 6.

7. Il Presidente presiede la Commissione di coordinamento del Sistema pubblico di connettivita' di cui all'articolo 80, comma 2, del Codice dell'amministrazione digitale, di cui al decreto legislativo n. 82 del 2005.

8. Il Presidente fa parte della Conferenza permanente per l'innovazione tecnologica di cui all'articolo 18, comma 2, del Codice dell'amministrazione digitale.

9. Per lo svolgimento delle sue funzioni il Presidente si avvale di un Ufficio dirigenziale avente competenza di supporto e di raccordo con gli altri organi. Tale ufficio svolge la propria attivita' secondo le direttive impartite dal Presidente. Alle dipendenze funzionali del Presidente e' posto, altresi', un Ufficio dirigenziale per il controllo strategico, ai sensi di quanto previsto nel decreto legislativo 30 luglio 1999, n. 286. Gli uffici dirigenziali di cui al presente comma sono compresi nell'ambito di quelli previsti all'articolo 11 e si avvalgono del personale di cui agli articoli 12 e 13.

10. Il Presidente puo' avvalersi di consiglieri con funzioni di supporto tecnico o scientifico, nell'ambito del contingente e con il trattamento economico di cui all'articolo 13, comma 2, scelti fra magistrati appartenenti alla giurisdizione ordinaria, amministrativa e contabile, avvocati dello Stato, dirigenti di prima fascia delle amministrazioni pubbliche ed equiparati, professori universitari di ruolo, estranei all'amministrazione dotati di qualificata competenza specifica. Ove pubblici dipendenti, detti consiglieri possono essere collocati in posizione di distacco, comando o fuori ruolo nell'amministrazione di provenienza secondo i rispettivi ordinamenti.

11. Al fine di assicurare il raccordo ed il monitoraggio delle attivita' tecnico-scientifiche di DigitPA, il Presidente convoca e presiede periodicamente una riunione con il Direttore Generale e i responsabili delle Aree.

### Art. 6. - Il Comitato direttivo

1. Il Comitato direttivo e' composto dal Presidente e da tre membri, scelti fra persone dotate di alta e riconosciuta competenza e professionalita' tecnica e gestionale. I componenti del Comitato direttivo sono nominati, su proposta del Ministro delegato, con decreto del Presidente del Consiglio dei Ministri. Il Comitato direttivo dura in carica quattro anni, i suoi componenti possono essere confermati una sola volta e ove pubblici dipendenti, sono collocati in posizione di fuori ruolo obbligatorio nell'amministrazione di provenienza secondo i rispettivi ordinamenti.

2. Il Comitato direttivo ha poteri di programmazione, indirizzo, controllo e regolazione dell'attivita' dell'Ente. In particolare, il Comitato direttivo delibera:

- a) il piano triennale di cui all'articolo 3, comma 1, e gli aggiornamenti annuali e ne verifica l'attuazione avvalendosi dell'Ufficio per il controllo strategico di cui all'articolo 5, comma 8;
- b) il bilancio di previsione, le variazioni di bilancio ed il rendiconto consuntivo che vengono trasmessi al Presidente del Consiglio o al Ministro delegato e al Ministero dell'economia e delle finanze;
- c) su proposta del Direttore Generale e nei limiti delle disponibilita' economiche e della dotazione organica di cui al presente decreto, le norme di organizzazione e funzionamento, di ordinamento del personale e di amministrazione e gestione delle risorse economiche e finanziarie dell'Ente. Tali delibere, che non possono comunque incidere sulle competenze e sulla dotazione organica fissate ai sensi del presente decreto, sono proposte al Presidente del Consiglio dei Ministri o al Ministro delegato che le adotta con decreto, di concerto con il Ministro dell'economia e delle finanze;
- d) su proposta del Direttore Generale, il disciplinare per l'individuazione delle prestazioni per le quali e' consentito il ristoro dei costi;
- e) i pareri di cui all'articolo 3, comma 3, e le regole, gli standard e le guide tecniche di cui all'articolo 3, comma 2, lettera b).

3. Ai fini delle deliberazioni, in caso di parita' di voti, prevale quello del Presidente.

### Art. 7. - Il Collegio dei revisori

1. Il Collegio dei revisori e' l'organo di controllo di regolarita' amministrativa e contabile previsto all'articolo 1, comma 2, lettera a), del decreto legislativo 30 luglio 1999, n. 286.

2. Il Collegio dei revisori e' composto da tre membri, di cui due iscritti al registro dei revisori contabili, nominati dal Presidente del Consiglio dei Ministri. L'incarico di Presidente e' conferito ad un dirigente di prima fascia dei ruoli della Presidenza del Consiglio dei Ministri, collocato in posizione di fuori ruolo per la durata dell'incarico. Uno dei componenti e' designato dal Ministro dell'economia e delle finanze e l'altro dal Presidente del Consiglio dei Ministri o dal Ministro delegato. Il Presidente del Consiglio dei Ministri, di concerto con il Ministro dell'economia e delle finanze, determina i compensi spettanti. I revisori dei conti durano in carica quattro anni e sono rinnovabili una sola volta.

3. Il Collegio di revisori svolge tutte le altre funzioni previste dall'ordinamento. Allo stesso e' affidato il controllo contabile di cui all'articolo 2409-bis del codice civile.

### Art. 8. - Il Direttore Generale

1. Il Direttore Generale, di cui all'articolo 11, comma 2, e' nominato con decreto del Presidente del Consiglio dei Ministri o del Ministro delegato. L'incarico e' conferito a persone di particolare e comprovata qualificazione professionale. E' responsabile dell'amministrazione dell'ente. A tale fine, sovrintende alla gestione amministrativa e finanziaria di DigitPA, esercita funzioni di coordinamento delle Aree operative e delle strutture dell'ente, formula proposte agli organi di indirizzo dell'ente, da' attuazione alle deliberazioni ed ai programmi da questi approvati ed assicura gli adempimenti di carattere tecnico-amministrativo di tutte le attivita' di DigitPA in relazione alle finalita' istituzionali. Dura in carica quattro anni e puo' essere confermato. Se dipendente statale o docente universitario, per l'intera durata dell'incarico, e' collocato, rispettivamente, nella posizione di fuori ruolo o di aspettativa.

2. Il Direttore Generale partecipa alle riunioni del Comitato direttivo e puo' chiederne la convocazione con specifica motivazione. Ha facolta' di intervento e proposta, senza diritto di voto.

3. Il Direttore Generale nell'assolvimento dei propri compiti e di quelli assegnatigli dal Presidente e dal Comitato direttivo, adotta le deliberazioni necessarie, ivi compresa la proposizione di azioni e la resistenza in giudizio. In attuazione del piano triennale e dei relativi aggiornamenti e delle deliberazioni adottate dal Comitato direttivo stipula, in nome e per conto dell'ente, convenzioni, accordi e contratti.

4. Il Direttore Generale coadiuva il Presidente nella predisposizione del Piano triennale di cui all'articolo 3, comma 1, e individua le risorse umane e finanziarie necessarie al fine.

5. Il Direttore Generale adotta i provvedimenti in materia di assunzione e gestione del personale, ivi compresi i provvedimenti di selezione. Assegna le risorse umane alle strutture di DigitPA con modalita' che garantiscano ampia flessibilita' nell'impiego di tali risorse.

6. Il Direttore Generale puo' conferire deleghe ai dirigenti mediante espressa attribuzione. Il Direttore Generale, sentito il Presidente, conferisce gli incarichi dirigenziali e stipula i relativi contratti; avanza proposte al Comitato direttivo sui provvedimenti organizzativi e di gestione previsti nel presente decreto; rappresenta DigitPA nei rapporti con le organizzazioni sindacali. In attuazione di quanto disposto all'articolo 5, comma 3, sentito il Presidente, attribuisce gli obiettivi specifici ai singoli dirigenti per la valutazione delle prestazioni; fornisce supporto agli organi di indirizzo; coordina l'attivita' di comunicazione esterna ed interna in riferimento alle finalita' ed ai compiti delle Aree e degli Uffici.

7. Alle dipendenze del Direttore Generale opera l'Area «Organizzazione, risorse umane e funzionamento».

8. Il Direttore Generale e' titolare dell'unico centro di responsabilita' amministrativa e predispone il bilancio di previsione e le variazioni di bilancio nonche' il rendiconto consuntivo annuale ed esercita le funzioni ad esso attribuite dal Regolamento per la gestione delle risorse economiche e finanziarie dell'Ente.

### Art. 9. - Incompatibilita'

1. Le cariche di Presidente, Direttore Generale e componente del Comitato direttivo sono incompatibili con cariche di governo e con incarichi politici elettivi di parlamentare nazionale ed europeo, di Presidente o Consigliere regionale e provinciale, di Sindaco o di Consigliere comunale e di componente delle relative giunte.

2. Il Presidente e i componenti del Comitato direttivo non possono ricoprire incarichi di responsabile delle strutture organizzative dell'Ente ovvero di componente di commissioni di concorso per il reclutamento di personale dell'Ente medesimo.

3. Il Presidente, il Direttore Generale e i componenti del Comitato direttivo non possono ricoprire il ruolo di amministratore o dipendente di qualsiasi societa'. Ferme restando le norme sulle incompatibilita' previste dalla disciplina del pubblico impiego, la carica di Direttore Generale e' incompatibile con lo svolgimento di qualsiasi altra attivita' professionale.

### Art. 10. - Indennita' e compensi

1. Le indennita' di carica del Presidente e del Direttore Generale sono determinate con decreto del Presidente del Consiglio dei Ministri, su proposta del Ministro delegato, di concerto con il Ministro dell'economia e delle finanze. In sede di prima attuazione sono confermate le indennita' percepite.

2. Ai tre componenti del Comitato direttivo spetta un'indennita' di importo pari al settanta per cento dell'indennita' del Presidente.

## Organizzazione di DigitPA e ordinamento del personale e di contabilita'

### Art. 11. - Organizzazione di DigitPA

1. DigitPA, nel definire l'assetto della sua struttura organizzativa, in applicazione dei principi stabiliti dalle norme generali sul funzionamento e organizzazione della pubblica amministrazione, distingue i compiti di indirizzo, di supervisione tecnico-operativa e di verifica dei risultati, riservati al Presidente ed al Comitato direttivo, dalle attivita' amministrative, finanziarie e contabili, riservate al Direttore Generale.

2. L'organizzazione di DigitPA, deliberata dal Comitato direttivo ai sensi dell'articolo 6, comma 2, lettera c), definita nel rispetto della dotazione organica stabilita ai sensi del presente decreto, prevede l'ufficio di livello dirigenziale generale del Direttore generale e, oltre alle due strutture di livello dirigenziale non generale, poste alle dipendenze del Presidente, di cui all'articolo 5, comma 9, e dell'area, di livello dirigenziale non generale, posta alle dipendenze del Direttore Generale, di cui all'articolo 8, comma 7, sedici uffici dirigenziali, di livello dirigenziale non generale, di cui sei definiti «aree operative» organizzate in relazione alle missioni affidate all'ente stesso.

### Art. 12. - Dotazione organica

1. La dotazione organica e' determinata nell'allegata Tabella A, che costituisce parte integrante del presente decreto. Con decreto del Presidente del Consiglio dei Ministri, su proposta del Ministro per la pubblica amministrazione e l'innovazione, di concerto con il Ministro dell'economia e delle finanze, la dotazione organica di DigitPA puo' essere rideterminata, nei limiti delle disponibilita' economiche e nel rispetto dei vincoli previsti dalla normativa vigente in materia di organici e di assunzioni di personale, a seguito dell'approvazione del Piano triennale di cui all'articolo 3, comma 1.

2. Per lo svolgimento dei propri compiti istituzionali, DigitPA puo' avvalersi, nei limiti della dotazione organica e della disponibilita' economica esistente, di personale in posizione di comando, distacco o fuori ruolo in misura non superiore ad un terzo della dotazione organica.

### Art. 13. - Contingente di personale con contratti di lavoro flessibile

1. Per lo svolgimento dei propri compiti istituzionali, DigitPA puo' ricorrere, nei limiti della disponibilita' economica esistente, alla stipula di contratti di lavoro flessibile per un numero non superiore a trenta unita'. In sede di prima attuazione, nel limite temporale di cui all'articolo 16, comma 3, il numero massimo del personale di cui al presente comma e' fissato nel limite di dieci unita'.

2. I contratti di cui al comma 1 possono essere stipulati, in misura non superiore a dieci, con esperti nelle materie di competenza dell'Ente, ai sensi dell'articolo 7, comma 6, del decreto legislativo n. 165 del 2001. Il trattamento economico degli esperti, stabilito in tre fasce retributive definite da apposito decreto del Ministro per la pubblica amministrazione e l'innovazione, di concerto con il Ministero dell'economia e delle finanze, previa delibera del Comitato direttivo, e' determinato in relazione alla professionalita' posseduta e alle funzioni che si intendono conferire.

3. I restanti venti contratti di lavoro di cui al comma 1 sono stipulati nel rispetto dell'articolo 36 del decreto legislativo n. 165 del 2001.

4. Il Piano triennale e i relativi aggiornamenti annuali determinano il fabbisogno complessivo di personale da utilizzare per gli obiettivi in esso individuati, nei limiti di quanto previsto nella tabella A e successive modifiche e delle disponibilita' economiche esistenti.

5. Per la realizzazione di progetti di innovazione tecnologica l'Ente puo', altresi', avvalersi di collaborazioni coordinate e continuative nonche' di incarichi di studio e consulenza, ai sensi dell'articolo 1, comma 188, della legge 23 dicembre 2005, n. 266.

### Art. 14. - Norme sul personale

1. L'assunzione del personale di ruolo avviene mediante procedure selettive nel rispetto degli articoli 35 e 36, comma 1, del decreto legislativo n. 165 del 2001. Allo stesso personale si applica quanto previsto all'articolo 70, comma 4, del citato decreto legislativo n. 165 del 2001. Il personale assunto ai sensi del presente comma e' iscritto, ai fini previdenziali all'Istituto nazionale di previdenza per i dipendenti dell'amministrazione pubblica (INPDAP).

2. I dipendenti dell'Ente conformano la propria condotta ai codici di comportamento dei dipendenti delle pubbliche amministrazioni e alle disposizioni contenute nel contratto collettivo nazionale di lavoro.

### Art. 15. - Regolamento di contabilita'

1. Con decreto del Presidente del Consiglio dei Ministri o del Ministro delegato, di concerto con il Ministro dell'economia e delle finanze, e' adottato, entro 180 giorni dall'entrata in vigore del presente decreto legislativo, il regolamento di contabilita' di DigitPA.

2. Nelle more dell'adozione del decreto di cui al comma 1, si applicano le norme transitorie di cui al Capo IV.

## Disposizioni transitorie in materia di personale e di ordinamento delle risorse economiche e finanziarie

### Art. 16. - Disciplina transitoria in materia di personale

1. I dipendenti gia' assunti con contratto a tempo indeterminato transitano direttamente nel ruolo dell'Ente sulla base dell'equiparazione di cui alla Tabella B, che costituisce parte integrante del presente decreto.

2. Il personale non dirigenziale in posizione di comando, distacco o fuori ruolo presso il CNIPA alla data di entrata in vigore del presente decreto, puo' presentare domanda per l'immissione nel ruolo di DigitPA; la predetta immissione avviene nei limiti delle posizioni di cui alla Tabella A e con le modalita' definite con apposite disposizioni deliberate dal Comitato direttivo, su proposta del Direttore Generale e con corrispondente riduzione delle dotazioni organiche degli Enti di provenienza, fermo restando quanto previsto dall'articolo 30 del decreto legislativo 30 marzo 2001, n. 165.

3. In via transitoria, fino alla stipula del primo contratto collettivo nazionale di lavoro del comparto di riferimento e comunque non oltre la durata del contratto individuale in essere, il personale, anche con qualifica dirigenziale, in servizio presso l'Ente alla data di entrata in vigore del presente decreto con contratto a tempo indeterminato o determinato o in posizione di comando, distacco o fuori ruolo, mantiene il trattamento economico in godimento. Continua ad applicarsi l'articolo 6 del decreto del Presidente del Consiglio dei Ministri 14 aprile 1994, n. 609.

4. Il personale in servizio alla data di entrata in vigore del presente decreto legislativo e' iscritto all'INPDAP, fatta salva la facolta', da esercitare entro sei mesi dalla medesima data, di optare per il mantenimento del diverso regime previdenziale in essere.

5. In sede di prima applicazione e fino alle delibere del Comitato direttivo, e comunque fino ad un massimo di dodici mesi dalla data di entrata in vigore del presente decreto, permane l'attuale struttura organizzativa del CNIPA.

6. Al fine di garantire la continuita' e la funzionalita' di DigitPA, nelle more dell'espletamento delle procedure concorsuali e comunque non oltre ventiquattro mesi dalla data di entrata in vigore del presente decreto, possono essere conferiti incarichi dirigenziali, nei limiti dei posti previsti nella dotazione organica, con contratti di lavoro a tempo determinato.

7. Entro trenta giorni dalla data di entrata in vigore del presente decreto legislativo, si provvede alla costituzione dei nuovi organi.

### Art. 17. - Contabilita' speciale

1. L'Ente provvede all'autonoma gestione delle spese per il proprio funzionamento e delle spese per la realizzazione di programmi, progetti ad esso affidati, nonche' di specifiche finalita' previste per legge, avvalendosi di una contabilita' speciale.

2. La gestione finanziaria e' sottoposta al controllo consuntivo della Corte dei conti.

### Art. 18. - Entrate

1. Le entrate dell'Ente, iscritte in un'unica sezione del bilancio di previsione, sono costituite:

- a) dal contributo finanziario ordinario dello Stato;
- b) dalle assegnazioni e dai contributi da parte di pubbliche amministrazioni centrali e locali per l'esecuzione di specifiche iniziative;
- c) dai contributi dell'Unione europea o di altri organismi internazionali per la partecipazione a programmi e progetti;
- d) dai contratti stipulati con terzi pubblici e privati per la fornitura di servizi;
- e) dai ricavi ottenuti attraverso la cessione di prodotti dell'ingegno o di know-how;
- f) da ogni altra eventuale entrata connessa alla sua attivita' o prevista dall'ordinamento;
- g) dall'avanzo presunto dell'esercizio precedente;
- h) entrate per partite di giro.

2. DigitPA destina una quota delle risorse di cui al comma 1, lettere a), b), c), f), g) ed h) al finanziamento delle assunzioni di personale ai fini della copertura dei posti in dotazione organica.

3. Nell'ambito di gare o accordi quadro predisposti direttamente o con altri soggetti, per l'espletamento delle funzioni di cui all'articolo 3, DigitPA riceve dalle amministrazioni contraenti, nell'ambito delle risorse ordinariamente destinate all'innovazione tecnologica, un contributo forfetario per spese di funzionamento secondo un importo determinato, in misura fissa ovvero compresa tra un minimo e un massimo, con decreto del Presidente del Consiglio dei Ministri, su proposta del Ministro per la pubblica amministrazione e l'innovazione, in percentuale sul valore del contratto sottoscritto. ((1))

------------- AGGIORNAMENTO (1) Il D.L. 7 maggio 2012, n. 52, convertito con modificazioni dalla L. 6 luglio 2012, n. 94, ha disposto (con l'art. 10, comma 1-bis) che "L'articolo 18, comma 3, del decreto legislativo 1° dicembre 2009, n. 177, si interpreta nel senso che il contributo forfetario non e' dovuto nel caso di gare predisposte dalle amministrazioni contraenti e per le quali sono stati chiesti a DigitPA i pareri di cui all'art. 3 dello stesso decreto".

### Art. 19. - Eccedenze di bilancio

1. All'Ente si applicano, ove non diversamente disposto e per quanto compatibili con il presente decreto, le disposizioni contenute nel decreto del Presidente del Consiglio dei Ministri 1° giugno 2007, n. 110. I termini: «Collegio» o: «Collegio del CNIPA» presenti nel citato decreto del Presidente del Consiglio dei Ministri n. 110 del 2007 sono sostituiti da: «Comitato direttivo». I termini: «CNIPA», «Centro Nazionale per l'informatica nella pubblica amministrazione», «Centro» sono sostituiti con: «DigitPA».

2. Sono abrogate le seguenti norme del decreto del Presidente del Consiglio dei Ministri 1° giugno 2007, n. 110:

- a) articolo 12, comma 4;
- b) articolo 29, comma 2;
- c) articolo 30;
- d) articolo 38, comma 8.

3. Qualora l'avanzo di esercizio di cui all'articolo 12 del decreto del Presidente del Consiglio dei Ministri 1° giugno 2007, n. 110, al netto delle somme vincolate, nonche' di quelle di cui al comma 5 del medesimo articolo e di cui all'articolo 15, comma 1, del medesimo decreto n. 110 del 2007, superi del dieci per cento l'importo della spesa sostenuta per il funzionamento, come risultante dal rendiconto finanziario, il Comitato direttivo delibera di versare l'eccedenza in entrata del bilancio dello Stato.

### Art. 20. - Attivita' commerciale

1. L'attivita' commerciale, svolta nel contesto delle funzioni istituzionali dell'ente, e' contabilizzata, ai fini fiscali, in forma separata, secondo i principi dell'ordinamento giuridico. Le relative risultanze sono evidenziate nella nota integrativa di cui all'articolo 16, comma 6, del decreto del Presidente del Consiglio dei Ministri 1° giugno 2007, n. 110.

## Disposizioni finali

### Art. 21. - Diritti di proprieta' intellettuale ed attivita' per conto terzi

1. Su proposta del Direttore Generale, con delibera del Comitato direttivo, sono disciplinati i diritti derivanti da invenzioni, brevetti industriali e da opere dell'ingegno, sviluppate nello svolgimento delle attivita' istituzionali in base alla normativa vigente.

2. Con la medesima procedura di cui al comma 1, sono altresi' definiti le modalita' ed i criteri di riparto dei proventi derivanti da contratti di consulenza e convenzioni per conto terzi.

### Art. 22. - Trasferimento delle funzioni

1. La funzione di coordinamento, attraverso la redazione di un piano triennale annualmente riveduto, dei progetti e dei principali interventi di sviluppo e gestione dei sistemi informativi automatizzati delle amministrazioni, e' trasferita al Presidente del Consiglio dei Ministri o al Ministro delegato.

2. La funzione di curare, nel settore delle tecnologie dell'informazione e della comunicazione nell'ambito della pubblica amministrazione, i rapporti con gli organi delle Comunita' europee e partecipare ad organismi comunitari ed internazionali, e' trasferita al Presidente del Consiglio dei Ministri o al Ministro delegato.

3. Il Presidente del Consiglio dei Ministri o il Ministro delegato trasmette al Parlamento, entro il 31 maggio di ogni anno, una relazione che dia conto dell'attivita' svolta nell'anno precedente e dello stato dell'informatizzazione nelle amministrazioni, con particolare riferimento al livello di utilizzazione effettiva delle tecnologie e ai relativi costi e benefici.

4. Le funzioni del CNIPA sono trasferite a DigitPA, secondo quanto disposto dal presente decreto.

### Art. 23. - Norma di salvaguardia

1. Dalla data di entrata in vigore del presente decreto, sono fatti salvi, fino alla loro naturale scadenza, i contratti e le convenzioni stipulati dalle pubbliche amministrazioni con il CNIPA.

### Art. 24. - Abrogazioni

1. Dalla data di entrata in vigore del presente decreto:

- a) gli articoli 4, 5, 6, 7, 8, 9 e 17 del decreto legislativo n. 39 del 1993 sono abrogati;
- b) all'articolo 10, comma 6-ter, del decreto legislativo 30 luglio 1999, n. 303, modificato dall'articolo 5 del decreto legislativo 5 dicembre 2003, n. 343, l'ultimo periodo e' soppresso;
- c) ad eccezione dell'articolo 6, il decreto del Presidente del Consiglio dei Ministri 14 aprile 1994, n. 609, recante regolamento recante norme per l'organizzazione ed il funzionamento della Autorita' per l'informatica nella pubblica amministrazione, e' abrogato.

2. La denominazione: «Centro nazionale per l'informatica nella pubblica amministrazione» ovunque presente nella vigente normativa e' sostituita dalla seguente: «DigitPA».

